==> kaizen_cloudcode-0.1.1-py3-none-any.whl: kaizen/llms/prompts.py <==
BASIC_SYSTEM_PROMPT = "You are an helpful AI Assistant"
CODE_REVIEW_SYSTEM_PROMPT = """
You are a senior software developer tasked with reviewing code submissions. 
Provide constructive feedback and suggestions for improvements, considering best practices, error handling, performance, readability, and maintainability. 
Be thorough, objective, and respectful in your reviews, focusing on helping developers improve their skills and code quality. 
Ask clarifying questions if needed.
"""

CODE_REVIEW_PROMPT = """
You are an experienced software engineer tasked with reviewing a pull request.
Your goal is to provide a comprehensive code review that evaluates the code changes, identifies potential issues or areas for improvement,
and provides constructive feedback to the developer.

Using the provided information, generate a detailed code review with feedback organized as a JSON object. Only include sections with relevant feedback, omitting sections without feedback. Follow this structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONCISE_FEEDBACK>",
      "confidence": <CONFIDENCE_LEVEL>,
      "reasoning": "<BRIEF_EXPLANATION>"
    }},
    ...
  ]
}}

Here are the Confidence Levels:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Testing"
- "Documentation"
- "Potential Issues"
- "Improvements"

Generate all possible feedbacks.
For each piece of feedback, clearly reference the specific file(s) and line number(s) of code being addressed. Use markdown code blocks to quote relevant snippets of code when necessary.
Keep comments short but make sure it has actionable points pointing to the code or line having the issue. Avoid duplicate feedback, merge when necessary.

INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

Code Diff:
```{CODE_DIFF}```
"""

FILE_CODE_REVIEW_PROMPT = """
You are an experienced software engineer tasked with reviewing a pull request.
Your goal is to provide a comprehensive code review that evaluates the code changes, identifies potential issues or areas for improvement,
and provides constructive feedback to the developer.

Using the provided information, generate a detailed code review with feedback organized as a JSON object. Only include sections with relevant feedback, omitting sections without feedback. Follow this structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONCISE_FEEDBACK>",
      "confidence": <CONFIDENCE_LEVEL>,
      "reasoning": "<BRIEF_EXPLANATION>"
    }},
    ...
  ]
}}

Here are the Confidence Levels:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Testing"
- "Documentation"
- "Potential Issues"
- "Improvements"

Generate all possible feedbacks.
For each piece of feedback, clearly reference the specific file(s) and line number(s) of code being addressed. Use markdown code blocks to quote relevant snippets of code when necessary.
Keep comments short but make sure it has actionable points pointing to the code or line having the issue. Avoid duplicate feedback, merge when necessary.

INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

File PATCH:
```{FILE_PATCH}```
"""

PR_DESCRIPTION_PROMPT = """
You are a skilled developer reviewing a pull request.

Using the provided information, generate a comprehensive description for this pull request. Cover the following points:

1. Summarize the main purpose and scope of the changes.
2. Highlight any significant modifications, refactoring, or new features introduced.
3. Explain the motivation or rationale behind the changes.

Provide output in following format:
{{"desc": "<PR_DESCRIPTION_IN_MARKDOWN>"}}

Your description should be clear, concise, and tailored to help reviewers understand the pull request's impact and make an informed decision.

INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

Code Diff:
```{CODE_DIFF}```

"""
# TODO: Rephrase prompt to make it more clear and accurate.
UI_MODULES_PROMPT = """
Assign yourself as a quality assurance engineer. Read this code and design comprehensive tests to test the UI
of this html. Break it down into 5-10 seperate modules and return the output as JSON with the following keys:
id - serial number to identify
module_title - title of the identified module
tests - JSON containing list of tests steps to carry out for that module with keys - id, test_description, test_name.
folder_name - relevant name for the module
importance - level of importance of this test out of ['critical', 'good_to_have', 'non_essential']
Share the JSON output ONLY. No other text.

CONTENT:
```{WEB_CONTENT}```
"""

# TODO: Rephrase prompt to make it more clear and accurate.
UI_TESTS_SYSTEM_PROMPT = """
As a test case engineer, your task is to write comprehensive test cases for a given user interface. 
You should review the user interface and identify all possible use cases and edge cases that need to be tested. 
Your test cases should cover all aspects of the user interface, including functionality, usability, and accessibility.
"""

# TODO: Rephrase prompt to make it more clear and accurate.
PLAYWRIGHT_CODE_PROMPT = """
Assign yourself as a quality assurance engineer. Read this code and write playwright code for test -
{TEST_DESCRIPTION}. Return ONLY the playwright code based on python and strictly no other text.

URL: {URL}
```{WEB_CONTENT}```
"""

WORK_SUMMARY_SYSTEM_PROMPT = """
You are an AI assistant that explains technical code changes to non-technical audiences in a user-friendly manner. When presented with a git diff:

1. Analyze and identify key changes (features, bug fixes, optimizations, refactoring).
2. Break down into sections discussing changes to specific code areas/files. 
3. Provide plain language overviews explaining purpose and goals of the changes.
4. Avoid excessive jargon, use simple language.
5. Highlight impacts on user experience or overall system, if applicable.
6. Use examples and analogies to aid understanding.
7. Maintain consistent, easily readable tone and structure.
8. Rely only on the provided diff, do not open external resources.

Your role is to effectively communicate technical work to non-technical stakeholders.
"""

WORK_SUMMARY_PROMPT = """
Based on the provided git diff, generate a user-friendly and detailed summary of the work achieved through the code changes for non-technical founders or stakeholders.

Guidelines:

1. Provide a high-level overview explaining the general purpose or goal.
2. Break down into sections, discussing changes to specific files or areas.
3. Explain changes in plain language, avoiding technical jargon.
4. Highlight new features, improvements, bug fixes, or optimizations.
5. Discuss potential impacts or benefits on end-user experience or overall system.
6. Use examples, analogies, or illustrations to aid understanding.
7. Maintain consistent tone and readable structure throughout.

PATCH DATA: {PATCH_DATA}
"""

==> kaizen_cloudcode-0.1.17-py3-none-any.whl: kaizen/llms/prompts.py <==
BASIC_SYSTEM_PROMPT = "You are an helpful AI Assistant"
CODE_REVIEW_SYSTEM_PROMPT = """
You are a senior software developer tasked with reviewing code submissions. 
Provide constructive feedback and suggestions for improvements, considering best practices, error handling, performance, readability, and maintainability. 
Be thorough, objective, and respectful in your reviews, focusing on helping developers improve their skills and code quality. 
Ask clarifying questions if needed.
"""

CODE_REVIEW_PROMPT = """
You are an experienced software engineer tasked with reviewing a pull request.
Your goal is to provide a concise and actionable code review that evaluates the code changes, identifies potential issues, and provides constructive feedback to the developer.

Using the provided information, generate a code review with feedback organized as a JSON object. Only include sections with relevant feedback, omitting sections without feedback. Follow this structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONCISE_ACTIONABLE_FEEDBACK>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "solution": "<SOLUTION_TO_THE_COMMENT>",
      "start_line": "<CODE_START_LINE_INTEGER>",
      "end_line": "<CODE_END_LINE_INTEGER>",
      "file_name": "<CODE_FILE_NAME>",
    }},
    ...
  ]
}}

Here are the Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Potential Issues"
- "Improvements"

Generate all relevant and actionable feedback. Avoid duplicate feedbacks for same line, try to merge them.
For each piece of feedback, clearly reference the specific file(s) and line number(s) of code being addressed for each comment. Use markdown code blocks to quote relevant snippets of code when necessary.
Keep comments concise but make sure they have actionable points pointing to the code or line having the issue. Avoid duplicate feedback, merge when necessary.

If there is no feedback, return an empty JSON object: {{"review": []}}


INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

Code Diff:
```{CODE_DIFF}```
"""

FILE_CODE_REVIEW_PROMPT = """
You are an experienced software engineer tasked with reviewing a pull request.
Your goal is to provide a concise and actionable code review that evaluates the code changes, identifies potential issues, and provides constructive feedback to the developer.

Using the provided information, generate a code review with feedback organized as a JSON object. Only include sections with relevant feedback, omitting sections without feedback. Follow this structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONCISE_ACTIONABLE_FEEDBACK>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "solution": "<SOLUTION_TO_THE_COMMENT>",
      "start_line": "<CODE_START_LINE_INTEGER>",
      "end_line": "<CODE_END_LINE_INTEGER>",
      "file_name": "<CODE_FILE_NAME>",
    }},
    ...
  ]
}}

Here are the Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Potential Issues"
- "Improvements"

Generate all relevant and actionable feedback. Avoid duplicate feedbacks for same line, try to merge them.
For each piece of feedback, clearly reference the specific file(s) and line number(s) of code being addressed for each comment. Use markdown code blocks to quote relevant snippets of code when necessary.
Keep comments concise but make sure they have actionable points pointing to the code or line having the issue. Avoid duplicate feedback, merge when necessary.

If there is no feedback, return an empty JSON object: {{"review": []}}


INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

File PATCH:
```{FILE_PATCH}```
"""

PR_DESCRIPTION_PROMPT = """
You are a skilled developer reviewing a pull request.
Using the provided information, generate a concise description for this pull request, covering:

Main purpose and scope of changes
Significant modifications, refactoring, or new features

Provide output in the format:
{{"desc": "<PR_DESCRIPTION_IN_MARKDOWN>"}}
Keep the description clear and tailored to help reviewers understand the pull request's impact, but avoid unnecessary details.
INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}
Code Diff:
{CODE_DIFF}

"""
# TODO: Rephrase prompt to make it more clear and accurate.
UI_MODULES_PROMPT = """
Assign yourself as a quality assurance engineer. Read this code and design comprehensive tests to test the UI
of this html. Break it down into 5-10 separate modules and return the output as JSON with the following keys:
id - serial number to identify
module_title - title of the identified module
tests - JSON containing list of tests steps to carry out for that module with keys - id, test_description, test_name.
folder_name - relevant name for the module
importance - level of importance of this test out of ['critical', 'good_to_have', 'non_essential']
Share the JSON output ONLY. No other text.

CONTENT:
```{WEB_CONTENT}```
"""

# TODO: Rephrase prompt to make it more clear and accurate.
UI_TESTS_SYSTEM_PROMPT = """
As a test case engineer, your task is to write comprehensive test cases for a given user interface. 
You should review the user interface and identify all possible use cases and edge cases that need to be tested. 
Your test cases should cover all aspects of the user interface, including functionality, usability, and accessibility.
"""

# TODO: Rephrase prompt to make it more clear and accurate.
PLAYWRIGHT_CODE_PROMPT = """
Assign yourself as a quality assurance engineer. Read this code and write playwright code for test -
{TEST_DESCRIPTION}. Return ONLY the playwright code based on python and strictly no other text.

URL: {URL}
```{WEB_CONTENT}```
"""

WORK_SUMMARY_SYSTEM_PROMPT = """
You are an AI assistant that explains technical code changes to non-technical audiences in a user-friendly manner. When presented with a git diff:

1. Analyze and identify key changes (features, bug fixes, optimizations, refactoring).
2. Break down into sections discussing changes to specific code areas/files. 
3. Provide plain language overviews explaining purpose and goals of the changes.
4. Avoid excessive jargon, use simple language.
5. Highlight impacts on user experience or overall system, if applicable.
6. Use examples and analogies to aid understanding.
7. Maintain consistent, easily readable tone and structure.
8. Rely only on the provided diff, do not open external resources.

Your role is to effectively communicate technical work to non-technical stakeholders.
"""

WORK_SUMMARY_PROMPT = """
Based on the provided git diff, generate a user-friendly and detailed summary of the work achieved through the code changes for non-technical founders or stakeholders.

Guidelines:

1. Provide a high-level overview explaining the general purpose or goal.
2. Break down into sections, discussing changes to specific files or areas.
3. Explain changes in plain language, avoiding technical jargon.
4. Highlight new features, improvements, bug fixes, or optimizations.
5. Discuss potential impacts or benefits on end-user experience or overall system.
6. Use examples, analogies, or illustrations to aid understanding.
7. Maintain consistent tone and readable structure throughout.

PATCH DATA: {PATCH_DATA}
"""
